@@ -9,6 +9,7 @@ define([
 		initialize: function(models, options) {
 			this.group = options.group;
 			this.domains = options.domains;
+			this.policies = options.policies;
 		},
 
 		url: function() {
@@ -19,6 +20,11 @@ define([
 					params.push("domain=" + domain);
 				});
 			}
+			if (this.policies) {
+				_.forEach(this.policies, function(policy) {
+					params.push("policy=" + policy);
+				});
+			}
 			if (params.length) {
 				url += "?" + params.join("&");
 			}
